(target-ethology)=
# ethology

[`ethology`](https://github.com/neuroinformatics-unit/ethology) is a Python package which aims to facilitate the application of a wide range of computer vision tasks to animal behaviour research, by providing a unified data analysis interface. We plan to support both classic computer vision tasks and deep learning based ones, such as background subtraction, object detection, ID tracking, segmentation, any-point tracking, and any useful combinations between them.

::::{grid} 1 2 2 3
:gutter: 3

:::{grid-item-card} {fas}`wrench;sd-text-primary` Installation
:link: installation
:link-type: doc

Installation instructions.
:::

:::{grid-item-card} {fas}`chalkboard-user;sd-text-primary` Examples
:link: examples/index
:link-type: doc

A gallery of examples using `ethology`.
:::


:::{grid-item-card} {fas}`comments;sd-text-primary` Join the Community
:link: community/index
:link-type: doc

Get in touch, request a feature or contribute to the project.
:::
::::

:::{warning}
🏗️ The package is currently in early development stages and the interface is subject to change. Feel free to play around and provide feedback.
:::

:::{tip}
If you are looking to analyse your pose estimation tracks with a user-friendly toolbox, check out our sister project
[movement](https://movement.neuroinformatics.dev)!
:::

```{toctree}
:maxdepth: 2
:hidden:

installation
examples/index
api_index
community/index
```
